@@ -67,55 +67,16 @@ macro_rules! concatcp {
 
 #[doc(hidden)]
 #[macro_export]
-#[cfg(not(feature = "rust_1_51"))]
-macro_rules! __concatcp_inner {
-    ($variables:expr) => {{
-        const ARR_LEN: usize = $crate::pmr::PArgument::calc_len($variables);
-
-        const CONCAT_ARR: &$crate::pmr::LenAndArray<[u8; ARR_LEN]> = {
-            use $crate::{__write_pvariant, pmr::PVariant};
-
-            let mut out = $crate::pmr::LenAndArray {
-                len: 0,
-                array: [0u8; ARR_LEN],
-            };
-
-            let input = $variables;
-
-            $crate::__for_range! { outer_i in 0..input.len() =>
-                let current = &input[outer_i];
-
-                match current.elem {
-                    PVariant::Str(s) => __write_pvariant!(str, current, s => out),
-                    PVariant::Int(int) => __write_pvariant!(int, current, int => out),
-                    PVariant::Char(c) => __write_pvariant!(char, current, c => out),
-                }
-            }
-            &{ out }
-        };
-
-        #[allow(clippy::transmute_ptr_to_ptr)]
-        const CONCAT_STR: &str = unsafe {
-            // This transmute truncates the length of the array to the amound of written bytes.
-            let slice =
-                $crate::pmr::transmute::<&[u8; ARR_LEN], &[u8; CONCAT_ARR.len]>(&CONCAT_ARR.array);
-
-            $crate::__priv_transmute_bytes_to_str!(slice)
-        };
-        CONCAT_STR
-    }};
-}
-
-#[doc(hidden)]
-#[macro_export]
-#[cfg(feature = "rust_1_51")]
 macro_rules! __concatcp_inner {
     ($variables:expr) => {{
+        #[doc(hidden)]
         const ARR_LEN: usize = $crate::pmr::PArgument::calc_len($variables);
 
+        #[doc(hidden)]
         const CONCAT_ARR: &$crate::pmr::LenAndArray<[u8; ARR_LEN]> =
             &$crate::pmr::__priv_concatenate($variables);
 
+        #[doc(hidden)]
         #[allow(clippy::transmute_ptr_to_ptr)]
         const CONCAT_STR: &str = unsafe {
             // This transmute truncates the length of the array to the amound of written bytes.
@@ -288,7 +249,7 @@ macro_rules! formatcp {
 ///
 /// # Stable equivalent
 ///
-/// For an equivalent macro which can be used in stable Rust (1.46.0 onwards),
+/// For an equivalent macro which can be used in stable Rust,
 /// but can only concatenate primitive types,
 /// you can use the [`concatcp`](crate::concatcp) macro.
 ///
@@ -435,7 +396,7 @@ macro_rules! __concatc_inner {
 ///
 /// # Stable equivalent
 ///
-/// For an equivalent macro which can be used in stable Rust (1.46.0 onwards),
+/// For an equivalent macro which can be used in stable Rust,
 /// but can only format primitive types,
 /// you can use the [`formatcp`](crate::formatcp) macro.
 ///
